==> php81-nextcloud-28.0.2.tgz: share/nextcloud/lib/l10n/ta.js <==
OC.L10N.register(
    "lib",
    {
    "Files" : "கோப்புகள்",
    "today" : "இன்று",
    "yesterday" : "நேற்று",
    "last month" : "கடந்த மாதம்",
    "last year" : "கடந்த வருடம்",
    "seconds ago" : "செக்கன்களுக்கு முன்",
    "__language_name__" : "தமிழ்",
    "Help" : "உதவி",
    "Apps" : "செயலிகள்",
    "Settings" : "அமைப்புகள்",
    "Log out" : "விடுபதிகை செய்க",
    "Users" : "பயனாளர்",
    "Email" : "மின்னஞ்சல்",
    "Phone" : "தொலைப்பேசி",
    "Address" : "முகவரி",
    "About" : "பற்றி",
    "Could not find category \"%s\"" : "பிரிவு \"%s\" ஐ கண்டுப்பிடிக்க முடியவில்லை",
    "Sunday" : "ஞாயிற்றுக்கிழமை",
    "Monday" : "திங்கட்கிழமை",
    "Tuesday" : "செவ்வாய்க்கிழமை",
    "Wednesday" : "புதன்கிழமை",
    "Thursday" : "வியாழக்கிழமை",
    "Friday" : "வெள்ளிக்கிழமை",
    "Saturday" : "சனிக்கிழமை",
    "Sun." : "ஞாயிறு",
    "Mon." : "திங்கள்",
    "Tue." : "செவ்வாய்",
    "Wed." : "புதன்",
    "Thu." : "வியாழன்",
    "Fri." : "வெள்ளி",
    "Sat." : "சனி",
    "January" : "தை",
    "February" : "மாசி",
    "March" : "பங்குனி",
    "April" : "சித்திரை",
    "May" : "வைகாசி",
    "June" : "ஆனி",
    "July" : "ஆடி",
    "August" : "ஆவணி",
    "September" : "புரட்டாசி",
    "October" : "ஐப்பசி",
    "November" : "கார்த்திகை",
    "December" : "மார்கழி",
    "Jan." : "தை",
    "Feb." : "மாசி",
    "Mar." : "பங்குனி",
    "Apr." : "சித்திரை",
    "May." : "வைகாசி",
    "Jun." : "ஆனி",
    "Jul." : "ஆடி",
    "Aug." : "ஆவணி",
    "Sep." : "புரட்டாதி",
    "Oct." : "ஐப்பசி",
    "Nov." : "கார்த்திகை",
    "Dec." : "மார்கழி",
    "Application is not enabled" : "செயலி இயலுமைப்படுத்தப்படவில்லை",
    "Authentication error" : "அத்தாட்சிப்படுத்தலில் வழு",
    "Token expired. Please reload page." : "அடையாளவில்லை காலாவதியாகிவிட்டது. தயவுசெய்து பக்கத்தை மீள் ஏற்றுக."
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-28.0.6.tgz: share/nextcloud/lib/l10n/ta.js <==
OC.L10N.register(
    "lib",
    {
    "Files" : "கோப்புகள்",
    "today" : "இன்று",
    "yesterday" : "நேற்று",
    "last month" : "கடந்த மாதம்",
    "last year" : "கடந்த வருடம்",
    "seconds ago" : "செக்கன்களுக்கு முன்",
    "__language_name__" : "தமிழ்",
    "Apps" : "செயலிகள்",
    "Settings" : "அமைப்புகள்",
    "Log out" : "விடுபதிகை செய்க",
    "Users" : "பயனாளர்",
    "Email" : "மின்னஞ்சல்",
    "Phone" : "தொலைப்பேசி",
    "Address" : "முகவரி",
    "About" : "பற்றி",
    "Could not find category \"%s\"" : "பிரிவு \"%s\" ஐ கண்டுப்பிடிக்க முடியவில்லை",
    "Sunday" : "ஞாயிற்றுக்கிழமை",
    "Monday" : "திங்கட்கிழமை",
    "Tuesday" : "செவ்வாய்க்கிழமை",
    "Wednesday" : "புதன்கிழமை",
    "Thursday" : "வியாழக்கிழமை",
    "Friday" : "வெள்ளிக்கிழமை",
    "Saturday" : "சனிக்கிழமை",
    "Sun." : "ஞாயிறு",
    "Mon." : "திங்கள்",
    "Tue." : "செவ்வாய்",
    "Wed." : "புதன்",
    "Thu." : "வியாழன்",
    "Fri." : "வெள்ளி",
    "Sat." : "சனி",
    "January" : "தை",
    "February" : "மாசி",
    "March" : "பங்குனி",
    "April" : "சித்திரை",
    "May" : "வைகாசி",
    "June" : "ஆனி",
    "July" : "ஆடி",
    "August" : "ஆவணி",
    "September" : "புரட்டாசி",
    "October" : "ஐப்பசி",
    "November" : "கார்த்திகை",
    "December" : "மார்கழி",
    "Jan." : "தை",
    "Feb." : "மாசி",
    "Mar." : "பங்குனி",
    "Apr." : "சித்திரை",
    "May." : "வைகாசி",
    "Jun." : "ஆனி",
    "Jul." : "ஆடி",
    "Aug." : "ஆவணி",
    "Sep." : "புரட்டாதி",
    "Oct." : "ஐப்பசி",
    "Nov." : "கார்த்திகை",
    "Dec." : "மார்கழி",
    "Application is not enabled" : "செயலி இயலுமைப்படுத்தப்படவில்லை",
    "Authentication error" : "அத்தாட்சிப்படுத்தலில் வழு",
    "Token expired. Please reload page." : "அடையாளவில்லை காலாவதியாகிவிட்டது. தயவுசெய்து பக்கத்தை மீள் ஏற்றுக.",
    "Help" : "உதவி"
},
"nplurals=2; plural=(n != 1);");
